@@ -19,7 +19,7 @@ from calculate.core.server.func import Action, Tasks
 from calculate.lib.cl_lang import setLocalTranslate, getLazyLocalTranslate
 from calculate.lib.utils.files import FilesError
 from calculate.desktop.desktop import DesktopError
-from calculate.client.client import ClientError
+from ..client import ClientError
 from calculate.lib.utils.samba import SambaError
 from calculate.lib.cl_template import TemplatesError
 
