@@ -511,15 +511,16 @@ class VariableClClientUserMountData(ReadonlyTableVariable):
                        self.Get('cl_replication_host'))
             else:
                 yield ("remote_profile", 'unix', '', '')
-            try:
+
                 for host, mount_path in zip(self.Get('cl_share_hosts'), self.Get('cl_share_mounts')):
-                    resource = host.split('/')[-1]
-                    host = host.replace('//', '', 1).split(f"/{resource}")[0]
-                    if mount_path.startswith('~/'):
-                        mount_path = f"{path.join(self.Get('ur_home_path'), mount_path.replace('~/', '', 1))}"
-                    yield (resource, resource, mount_path, host)
-            except:
-                raise GeneratorExit
+                    try:
+                        resource = host.split('/')[-1]
+                        host = host.replace('//', '', 1).split(f"/{resource}")[0]
+                        if mount_path.startswith('~/'):
+                            mount_path = f"{path.join(self.Get('ur_home_path'), mount_path.replace('~/', '', 1))}"
+                        yield (resource, resource, mount_path, host)
+                    except:
+                        continue
 
         return list(generate())
 
